#!/usr/bin/python
# IBM WebSphere eXtreme Scale Pattern
# 
# Copyright IBM Corp. 2017
# All rights reserved.
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp.
# 
# Licensed Materials-Property of IBM
#

import os
import sys
import xsldUtils
import urllib2
import json
import logging
import time
import optparse

parser = optparse.OptionParser()
parser.add_option("--description")
(options, args) = parser.parse_args()

logging.basicConfig()
logger = logging.getLogger("xsld/createdatagrid.py")
logger.debug('WebSphere eXtreme Scale Liberty Deployment create grid script.')

if len(sys.argv) < 16:
   log.error('Too few arguments were provided')
   sys.exit(1)

xsadminPwd = sys.argv[1]
gridName = sys.argv[2]
owner = sys.argv[3]
useAuthentication = sys.argv[4]
useAuthorization = sys.argv[5]
gridCapacity = sys.argv[6]
useCapLRUEvictor = sys.argv[7]
transactionTimeout = sys.argv[8]
numPartition = sys.argv[9]
numSyncReplicas = sys.argv[10]
numAsyncReplicas = sys.argv[11]
timeToLive = sys.argv[12]
lockTimeout = sys.argv[13]
gridType = sys.argv[14]
description = options.description

if transactionTimeout == "0":
   logger.error("The transactionTimeout must be above 0")
   sys.exit(1)

if gridCapacity != "0":
   gridCapacityStr = '"gridCapacity": "%s",' % (gridCapacity)
else:
   gridCapacityStr = ''

# Match UI string to REST API string if Dynacache is selected
if gridType == "Dynamic Cache":
   gridType = "DynaCache"

hostname='localhost'

s = "xsadmin:" + xsadminPwd
auth = "Basic " + s.encode("base64").rstrip()

url = 'https://%s:9445/wxsadmin/v1/grid/%s' % (hostname,gridName)
data = '{ \
"description": "%s", \
"ownerName": "%s", \
"useAuthentication": %s, \
"useAuthorization": %s, %s \
"useCapLRUEvictor": %s, \
"transactionTimeout": "%s", \
"numPartition": "%s", \
"numSyncReplicas": "%s", \
"numAsyncReplicas": "%s", \
"timeToLive": "%s", \
"lockTimeout": "%s", \
"gridType": "%s" \
}' % (description,owner,useAuthentication,useAuthorization,gridCapacityStr,useCapLRUEvictor,transactionTimeout,numPartition,numSyncReplicas,numAsyncReplicas,timeToLive,lockTimeout,gridType)

clen = len(data)
headers = {'Authorization': auth, 'Content-type': 'application/json', 'Accept': 'application/json', 'Content-Length': clen}
req = urllib2.Request(url, headers=headers, data=data)
req.get_method = lambda: "POST"

response = xsldUtils.openURL(req,logger)
if response is None:
   logger.debug('Failed to get response from URL %s' % (url))
   sys.exit(1)

jsonData = json.loads(response)
xsldUtils.waitForTask(hostname, xsadminPwd, jsonData['taskid'])
